<div style="display: none;">
    <input type="hidden" name="product" value="{{product.pk}}">
    <input type="hidden" name="quantity" value="{{quantity}}">
    <input type="hidden" name="_action" value="{{action}}">
</div>