{% spaceless %}
{% load i18n %}
{% load pytils_numeral %}
<html>
<head>
    <meta http-equiv="content-type" content="text/html; charset=utf-8">
</head>
<body>
    {% block header %}
    <h1>New order <b>{{order.number}}</b></h1>
    {% endblock %}
    
    {% block user %}
    {% with order.user as user %}
    <h3>{{user.first_name}} {{user.last_name}} &lt;{{user.email}}&gt;</h3>
    {% endwith %}
    {% endblock %}

    {% block goods %}
    <table border="0" cellspacing="5" cellpadding="5">
        <thead>
            {% block goods_head %}
            <tr>
                <th>Product</th>
                <th>Price</th>
                <th>Quantity</th>
                <th>Total</th>
            </tr>
            {% endblock goods_head %}
        </thead>
        <tbody>
            {% block goods_body %}
                {% for item in cart %}
                    <tr>
                        <td>{{item.product.name}}</td>
                        <td>{{item.product.price}}</td>
                        <td>{{item.quantity}}</td>
                        <td>{{item.price_total}}</td>
                    </tr>
                {% endfor %}
            {% endblock goods_body %}
        </tbody>
        <tfoot>
            {% block goods_foot %}
            <tr>
                <td colspan="3">&nbsp;</td>
                <td><h3>{{total}}</h3></td>
            </tr>
            {% endblock goods_foot %}
        </tfoot>
    </table>
    {% endblock goods %}
    
    {% block content %}{% endblock%}
</body>
</html>
{% endspaceless %}