{% load plugshop %}
<div>
    <h2>Cart:</h2>
    {% if request.cart|length %}
    <table border="0" cellspacing="5" cellpadding="5">
        {% for cart_item in request.cart %}
            <tr>
                <td>
                    <a href="{{cart_item.product.get_absolute_url}}">{{cart_item.product}}</a>
                </td>
                <td>{{cart_item.quantity}}</td>
                <td>{{cart_item.price_total}}</td>
                <td>

                    <form action="{% url plugshop-cart %}" method="post">{% csrf_token %}
                        {% plugshop_action cart_item.product "add" 1 %}
                        <p>
                            <input type="submit" value="+">
                        </p>
                    </form>

                    <form action="{% url plugshop-cart %}" method="post">{% csrf_token %}
                        {% plugshop_action cart_item.product "remove" 1 %}
                        <p>
                            <input type="submit" value="-">
                        </p>
                    </form>

                    <form action="{% url plugshop-cart %}" method="post">{% csrf_token %}
                        {% plugshop_action cart_item.product "remove_product" %}
                        <p>
                            <input type="submit" value="x">
                        </p>
                    </form>

                </td>
            </tr>
        {% endfor %}
    </table>
    <div>
        Total: {{cart.price_total}}
    </div>
    {% endif %}
    <form action="{% url plugshop-cart %}" method="post">{% csrf_token %}
        <p>
            <input type="hidden" name="_action" value="remove_all">
            <input type="submit" value="empty">
        </p>
    </form>
</div>