<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title></title>
</head>
<body>
    {% block breadcrumbs %}
        <div>{% include "plugshop/category_path.html" with category=category %}</div>
    {% endblock breadcrumbs %}    
    
    {% block cart %}
        <div>{% include "plugshop/_cart.html" %}</div>
    {% endblock cart %}
    
    {% block content %}{% endblock content %}
</body>
</html>